@@ -37,4 +37,4 @@ class MiApi:
         api = mi.Api(self.ip, self.port, self.usr, self.pwd)
         result = api.request(program, transaction, **kwargs)
 
-        return parser.parse_mi_xml(result.content)
+        return result
\ No newline at end of file
